.card {
  box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
  transition: transform 0.3s ease, box-shadow 0.3s ease;
}
.card:hover {
  transform: translateY(-5px);
  box-shadow: 0 8px 16px rgba(0, 0, 0, 0.15);
}
html {
  scroll-behavior: smooth;
}
.container {
  display: flex;
  flex-wrap: wrap;
  gap: 20px;
  margin: 0 auto;
  max-width: 1200px;
}
button,
.btn {
  background: #17a2b8;
  color: #fff;
  border: none;
  padding: 10px 20px;
  border-radius: 5px;
  cursor: pointer;
  transition: background 0.3s ease, transform 0.3s ease;
}
button:hover,
.btn:hover {
  background: #138496;
  transform: translateY(-3px);
}
a {
  color: #17a2b8;
  text-decoration: none;
  transition: color 0.3s ease;
}
a:hover {
  color: #138496;
}

.testimonials-carousel {
  background: linear-gradient(to right, #eaf4f4, #fefefe);
  padding: 60px 20px;
  text-align: center;
}

.testimonials-carousel h3 {
  font-size: 2.2rem;
  margin-bottom: 40px;
  color: #05445e;
  font-weight: 600;
}

.carousel {
  position: relative;
  max-width: 700px;
  margin: auto;
  overflow: hidden;
  min-height: 160px;
}

.testimonial {
  position: absolute;
  opacity: 0;
  transition: opacity 1s ease-in-out;
  background-color: white;
  padding: 25px 30px;
  margin: 0 auto;
  box-shadow: 0 4px 12px rgba(0, 0, 0, 0.1);
  border-left: 5px solid #189ab4;
  border-radius: 12px;
  width: 100%;
}

.testimonial.active {
  opacity: 1;
  position: relative;
}

.testimonial p {
  font-size: 1.2rem;
  font-style: italic;
  color: #333;
}

.testimonial span {
  display: block;
  margin-top: 10px;
  font-weight: bold;
  color: #189ab4;
}

nav ul li a i {
  margin-right: 6px;
}

.floating-shape {
  position: absolute;
  border-radius: 50%;
  background: radial-gradient(circle at center, #00b4d8, #0077b6);
  width: 200px;
  height: 200px;
  opacity: 0.3;
  animation: float 8s ease-in-out infinite;
  z-index: 0;
}

.floating-shape.one {
  top: -50px;
  left: -50px;
}

.floating-shape.two {
  bottom: -60px;
  right: -40px;
}

@keyframes float {
  0% {
    transform: translateY(0px) scale(1);
  }
  50% {
    transform: translateY(-30px) scale(1.05);
  }
  100% {
    transform: translateY(0px) scale(1);
  }
}

.floating-shape {
  position: absolute;
  width: 60px;
  height: 60px;
  border-radius: 50%;
  opacity: 0.2;
  animation: float 6s ease-in-out infinite;
  z-index: 0;
}

.floating-shape.one {
  top: 20px;
  left: 15%;
  background: radial-gradient(circle at center, #00c6ff, #0072ff);
}

.floating-shape.two {
  bottom: 30px;
  right: 10%;
  background: radial-gradient(circle at center, #ff6a00, #ee0979);
  animation-delay: 3s;
}

@keyframes float {
  0%,
  100% {
    transform: translateY(0px);
  }
  50% {
    transform: translateY(-20px);
  }
}
